"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isGetCall = exports.isDefineCall = exports.isCustomElementsRegistry = void 0;
/**
 * Determines if a node is a `customElements` reference
 * @param {ESTree.Node} node Node to test
 * @return {boolean}
 */
function isCustomElementsRegistry(node) {
    return ((node.type === 'Identifier' && node.name === 'customElements') ||
        (node.type === 'MemberExpression' &&
            node.object.type === 'Identifier' &&
            (node.object.name === 'window' || node.object.name === 'globalThis') &&
            node.property.type === 'Identifier' &&
            node.property.name === 'customElements'));
}
exports.isCustomElementsRegistry = isCustomElementsRegistry;
/**
 * Determines if a call expression is a `customElements.define` call
 * @param {ESTree.CallExpression} node Node to test
 * @return {boolean}
 */
function isDefineCall(node) {
    return (node.callee.type === 'MemberExpression' &&
        isCustomElementsRegistry(node.callee.object) &&
        node.callee.property.type === 'Identifier' &&
        node.callee.property.name === 'define');
}
exports.isDefineCall = isDefineCall;
/**
 * Determines if a call expression is a `customElements.get` call
 * @param {ESTree.CallExpression} node Node to test
 * @return {boolean}
 */
function isGetCall(node) {
    return (node.callee.type === 'MemberExpression' &&
        isCustomElementsRegistry(node.callee.object) &&
        node.callee.property.type === 'Identifier' &&
        node.callee.property.name === 'get');
}
exports.isGetCall = isGetCall;
