"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isThisOrShadowRoot = exports.childMethodList = exports.childPropertyList = void 0;
exports.childPropertyList = new Set([
    // ParentNode
    'childElementCount',
    'children',
    'firstElementChild',
    'lastElementChild',
    // Node
    'childNodes',
    'firstChild',
    'innerHTML',
    'innerText',
    'lastChild',
    'textContent'
]);
exports.childMethodList = new Set([
    // Document
    'getElementById',
    'getElementsByClassName',
    'getElementsByTagName',
    // ParentNode
    'querySelector',
    'querySelectorAll',
    // Node
    'contains',
    'hasChildNodes',
    'insertBefore',
    'removeChild',
    'replaceChild'
]);
/**
 * Determines if a node is `this.*` or `this.shadowRoot.*`
 * @param {ESTree.Node} node Node to test
 * @return {boolean}
 */
function isThisOrShadowRoot(node) {
    return (node.type === 'ThisExpression' ||
        (node.type === 'MemberExpression' &&
            node.object.type === 'ThisExpression' &&
            node.property.type === 'Identifier' &&
            node.property.name === 'shadowRoot'));
}
exports.isThisOrShadowRoot = isThisOrShadowRoot;
