"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.toCaseByType = exports.toCamelCase = exports.toPascalCase = exports.toSnakeCase = exports.toKebabCase = void 0;
/**
 * Converts a _spaceless_ string to kebab-case
 * @param {string} str String to convert
 * @return {string}
 */
function toKebabCase(str) {
    return str
        .replace(/([A-Z]($|[a-z]))/g, '-$1')
        .replace(/^-/g, '')
        .toLowerCase();
}
exports.toKebabCase = toKebabCase;
/**
 * Converts a _spaceless_ string to snake_case
 * @param {string} str String to convert
 * @return {string}
 */
function toSnakeCase(str) {
    return str
        .replace(/([A-Z]($|[a-z]))/g, '_$1')
        .replace(/^_/g, '')
        .toLowerCase();
}
exports.toSnakeCase = toSnakeCase;
/**
 * Converts a _spaceless_ string to PascalCase
 * @param {string} str String to convert
 * @return {string}
 */
function toPascalCase(str) {
    if (str.length === 0) {
        return str;
    }
    return str[0].toUpperCase() + str.slice(1);
}
exports.toPascalCase = toPascalCase;
/**
 * Converts a _spaceless_ string to camelCase
 * @param {string} str String to convert
 * @return {string}
 */
function toCamelCase(str) {
    if (str.length === 0) {
        return str;
    }
    return str[0].toLowerCase() + str.slice(1);
}
exports.toCamelCase = toCamelCase;
/**
 * Converts a _spaceless_ string to the specified type of casing
 * @param {string} str String to convert
 * @param {string} type Type of casing
 * @return {string}
 */
function toCaseByType(str, type) {
    switch (type) {
        case 'kebab':
            return toKebabCase(str);
        case 'camel':
            return toCamelCase(str);
        case 'snake':
            return toSnakeCase(str);
        case 'pascal':
            return toPascalCase(str);
        case 'none':
            return str;
    }
}
exports.toCaseByType = toCaseByType;
